==> staging-demo-20260207_095928.tar.gz: var/www/html/staging-demo/var/tmp/twig/ee/eef31190fab96f23e105b44ef4eb8119.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticReport/Report/_details_content_footer.html.twig */
class __TwigTemplate_a9f907fad67cb4474ed582825f01d057 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "</div>
";
        // line 2
        if ((array_key_exists("debug", $context) && CoreExtension::getAttribute($this->env, $this->source, ($context["debug"] ?? null), "count_query", [], "any", true, true, false, 2))) {
            // line 3
            yield "  <div class=\"well\">
      <h4>Debug: ";
            // line 4
            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(CoreExtension::getAttribute($this->env, $this->source, (isset($context["debug"]) || array_key_exists("debug", $context) ? $context["debug"] : (function () { throw new RuntimeError('Variable "debug" does not exist.', 4, $this->source); })()), "query_time", [], "any", false, false, false, 4), "html", null, true);
            yield "</h4>
      <div>";
            // line 5
            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(CoreExtension::getAttribute($this->env, $this->source, (isset($context["debug"]) || array_key_exists("debug", $context) ? $context["debug"] : (function () { throw new RuntimeError('Variable "debug" does not exist.', 5, $this->source); })()), "count_query", [], "any", false, false, false, 5), "html", null, true);
            yield "</div>
      <br />
      <div>";
            // line 7
            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(CoreExtension::getAttribute($this->env, $this->source, (isset($context["debug"]) || array_key_exists("debug", $context) ? $context["debug"] : (function () { throw new RuntimeError('Variable "debug" does not exist.', 7, $this->source); })()), "query", [], "any", false, false, false, 7), "html", null, true);
            yield "</div>
  </div>
";
        }
        // line 10
        yield "<!--/ end: box layout -->
<input type=\"hidden\" name=\"entityId\" id=\"entityId\" value=\"";
        // line 11
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(CoreExtension::getAttribute($this->env, $this->source, (isset($context["report"]) || array_key_exists("report", $context) ? $context["report"] : (function () { throw new RuntimeError('Variable "report" does not exist.', 11, $this->source); })()), "id", [], "any", false, false, false, 11));
        yield "\"/>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticReport/Report/_details_content_footer.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  68 => 11,  65 => 10,  59 => 7,  54 => 5,  50 => 4,  47 => 3,  45 => 2,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticReport/Report/_details_content_footer.html.twig", "/var/www/html/staging-demo/app/bundles/ReportBundle/Resources/views/Report/_details_content_footer.html.twig");
    }
}

==> staging-demo-20260215_195515.tar.gz: var/www/html/staging-demo/var/tmp/twig/ee/eef31190fab96f23e105b44ef4eb8119.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticReport/Report/_details_content_footer.html.twig */
class __TwigTemplate_a9f907fad67cb4474ed582825f01d057 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "</div>
";
        // line 2
        if ((array_key_exists("debug", $context) && CoreExtension::getAttribute($this->env, $this->source, ($context["debug"] ?? null), "count_query", [], "any", true, true, false, 2))) {
            // line 3
            yield "  <div class=\"well\">
      <h4>Debug: ";
            // line 4
            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(CoreExtension::getAttribute($this->env, $this->source, (isset($context["debug"]) || array_key_exists("debug", $context) ? $context["debug"] : (function () { throw new RuntimeError('Variable "debug" does not exist.', 4, $this->source); })()), "query_time", [], "any", false, false, false, 4), "html", null, true);
            yield "</h4>
      <div>";
            // line 5
            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(CoreExtension::getAttribute($this->env, $this->source, (isset($context["debug"]) || array_key_exists("debug", $context) ? $context["debug"] : (function () { throw new RuntimeError('Variable "debug" does not exist.', 5, $this->source); })()), "count_query", [], "any", false, false, false, 5), "html", null, true);
            yield "</div>
      <br />
      <div>";
            // line 7
            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(CoreExtension::getAttribute($this->env, $this->source, (isset($context["debug"]) || array_key_exists("debug", $context) ? $context["debug"] : (function () { throw new RuntimeError('Variable "debug" does not exist.', 7, $this->source); })()), "query", [], "any", false, false, false, 7), "html", null, true);
            yield "</div>
  </div>
";
        }
        // line 10
        yield "<!--/ end: box layout -->
<input type=\"hidden\" name=\"entityId\" id=\"entityId\" value=\"";
        // line 11
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(CoreExtension::getAttribute($this->env, $this->source, (isset($context["report"]) || array_key_exists("report", $context) ? $context["report"] : (function () { throw new RuntimeError('Variable "report" does not exist.', 11, $this->source); })()), "id", [], "any", false, false, false, 11));
        yield "\"/>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticReport/Report/_details_content_footer.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  68 => 11,  65 => 10,  59 => 7,  54 => 5,  50 => 4,  47 => 3,  45 => 2,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticReport/Report/_details_content_footer.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/ReportBundle/Resources/views/Report/_details_content_footer.html.twig");
    }
}
